==> drd-8.x-3.10.tar.gz: drd/src/Plugin/Block/Base.php <==
<?php

namespace Drupal\drd\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\drd\ContextProvider\RouteContext;
use Symfony\Component\DependencyInjection\ContainerInterface;

abstract class Base extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * @var \Drupal\drd\ContextProvider\RouteContext.
   */
  protected $context;

  /**
   * Creates a RemoteBlock instance.
   *
   * @param array $configuration
   * @param string $plugin_id
   * @param array $plugin_definition
   * @param \Drupal\drd\ContextProvider\RouteContext $context
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, $context = NULL) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->context = $context;
  }

  /**
   * @inheritDoc
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      RouteContext::findDrdContext()
    );
  }

  /**
   * @inheritDoc
   */
  public function getCacheMaxAge() {
    return 0;
  }

  /**
   * @return bool
   */
  protected function isDrdContext() {
    return $this->context ? (bool) $this->context->getEntity() : FALSE;
  }

  /**
   * @return bool|\Drupal\drd\Entity\BaseInterface
   */
  protected function getEntity() {
    return $this->context ? $this->context->getEntity() : FALSE;
  }

}

==> drd-8.x-3.14.tar.gz: drd/src/Plugin/Block/Base.php <==
<?php

namespace Drupal\drd\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\drd\ContextProvider\RouteContext;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Abstract class for DRD blocks.
 */
abstract class Base extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * Route context of current request.
   *
   * @var \Drupal\drd\ContextProvider\RouteContext
   */
  protected $context;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, $context = NULL) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->context = $context;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      RouteContext::findDrdContext()
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge() {
    return 0;
  }

  /**
   * Determine if the current request is within the context of a DRD entity.
   *
   * @return bool
   *   TRUE if context is within a DRD entity.
   */
  protected function isDrdContext() {
    return $this->context ? (bool) $this->context->getEntity() : FALSE;
  }

  /**
   * Get the entity of the current context.
   *
   * @return bool|\Drupal\drd\Entity\BaseInterface
   *   The DRD entity if within an entity context or FALSE otherwise.
   */
  protected function getEntity() {
    return $this->context ? $this->context->getEntity() : FALSE;
  }

}
